import pytest


@pytest.fixture
def data_entity_usage_request():
    from alvin_api_client.model.data_entity_usage_stats_request import DataEntityUsageStatsRequest
    return DataEntityUsageStatsRequest


def test_data_entity_usage_request(
    data_entity_usage_request,
    query_builder,
    operator_type,
):
    OPERATOR = 'AND'
    query_builder_instance = query_builder(
        operator_type(OPERATOR)
    )
    model = data_entity_usage_request(
        query_builder_instance
    )
    assert {
        'query_builder': {
            'operator_type': OPERATOR
        }
    } == model.to_dict()



# flake8: noqa

"""
    Alvin

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


__version__ = "0.7.0"

# import ApiClient
from alvin_api_client.api_client import ApiClient

# import Configuration
from alvin_api_client.configuration import Configuration

# import exceptions
from alvin_api_client.exceptions import OpenApiException
from alvin_api_client.exceptions import ApiAttributeError
from alvin_api_client.exceptions import ApiTypeError
from alvin_api_client.exceptions import ApiValueError
from alvin_api_client.exceptions import ApiKeyError
from alvin_api_client.exceptions import ApiException



import pytest
import alvin_api_client


@pytest.fixture
def config_class():
    """The Configuration class, used to configure instances of ApiClient class.
    
    Instances of the Configuration class are passed in the constructor of the
    ApiClient class.
    """
    from alvin_api_client import Configuration
    return Configuration


@pytest.fixture
def localhost_configuration(config_class):
    """Create a Configuration for localhost with the specified port number.

    Create an instance for the Configuration class, assigning as the 'host'
    parameter 'localhost' and appending 'port number' parameter at runtime.

    Usefull when running tests and the API service (the one that the ApiClient
    "wraps around") is served on localhost.
    """
    def localhost_configuration(port_number: int):
        """Create a Configuration for localhost with the specified port number.

        Args:
            port_number (int): port number on localhost to "listen" to

        Returns:
            Configuration: instance of a localhost configuration
        """
        return config_class(
            host=f'http://localhost:{port_number}'
        )
    return localhost_configuration


@pytest.fixture
def api_client():
    from alvin_api_client import ApiClient
    def get_api_client_instance(configuration):
        return ApiClient(configuration)
    return get_api_client_instance



@pytest.fixture
def localhost_api_client(api_client, localhost_configuration):
    def get_localhost_api_client_instance(port_number):
        return api_client(localhost_configuration(port_number))
    return get_localhost_api_client_instance



@pytest.fixture
def default_api():
    """Create instances of the DefaultApi class."""
    from alvin_api_client.api.default_api import DefaultApi
    return DefaultApi



@pytest.fixture
def call_api():
    """Make a call to the API, through the API client."""
    def call_client_method(api_instance, method: str, *args, **kwargs):
        """Call a method on the client, matching an endpoint of the API."""
        return getattr(api_instance, method)(*args, **kwargs)
    return call_client_method



@pytest.fixture
def test_client_method(call_api):
    """Make a call to the API and validate expected results."""
    def test_api_client_call(api_instance, method: str, input, assert_callback):
        """Call a method of the API client, and validate expected results."""
        result = call_api(api_instance, method, *input[0], **input[1])
        assert_callback(result)
    return test_api_client_call



# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from alvin_api_client.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from alvin_api_client.model.api_key_scope import APIKeyScope
from alvin_api_client.model.api_key_status import APIKeyStatus
from alvin_api_client.model.api_keys_response import APIKeysResponse
from alvin_api_client.model.accept_invite_request import AcceptInviteRequest
from alvin_api_client.model.admin_config import AdminConfig
from alvin_api_client.model.airflow_additional_config import AirflowAdditionalConfig
from alvin_api_client.model.alter_parse_result import AlterParseResult
from alvin_api_client.model.alter_type import AlterType
from alvin_api_client.model.alvin_description_request import AlvinDescriptionRequest
from alvin_api_client.model.auth_provider import AuthProvider
from alvin_api_client.model.bi_platform import BiPlatform
from alvin_api_client.model.big_query_account_details import BigQueryAccountDetails
from alvin_api_client.model.big_query_additional_config import BigQueryAdditionalConfig
from alvin_api_client.model.classification_match_type import ClassificationMatchType
from alvin_api_client.model.classification_type import ClassificationType
from alvin_api_client.model.client_auth_config import ClientAuthConfig
from alvin_api_client.model.client_config import ClientConfig
from alvin_api_client.model.client_config_post_auth import ClientConfigPostAuth
from alvin_api_client.model.column_alter import ColumnAlter
from alvin_api_client.model.column_target import ColumnTarget
from alvin_api_client.model.comparison_operator import ComparisonOperator
from alvin_api_client.model.config_type import ConfigType
from alvin_api_client.model.connection_direction import ConnectionDirection
from alvin_api_client.model.connection_type import ConnectionType
from alvin_api_client.model.connection_usage_classification import ConnectionUsageClassification
from alvin_api_client.model.data_entity_connection import DataEntityConnection
from alvin_api_client.model.data_entity_connection_get import DataEntityConnectionGet
from alvin_api_client.model.data_entity_connection_type import DataEntityConnectionType
from alvin_api_client.model.data_entity_delete_tag_connection_request import DataEntityDeleteTagConnectionRequest
from alvin_api_client.model.data_entity_dependency_direction import DataEntityDependencyDirection
from alvin_api_client.model.data_entity_dependency_get import DataEntityDependencyGet
from alvin_api_client.model.data_entity_get import DataEntityGet
from alvin_api_client.model.data_entity_id import DataEntityID
from alvin_api_client.model.data_entity_job_run import DataEntityJobRun
from alvin_api_client.model.data_entity_job_run_type import DataEntityJobRunType
from alvin_api_client.model.data_entity_job_step import DataEntityJobStep
from alvin_api_client.model.data_entity_lineage import DataEntityLineage
from alvin_api_client.model.data_entity_lineage_children_item import DataEntityLineageChildrenItem
from alvin_api_client.model.data_entity_lineage_children_request import DataEntityLineageChildrenRequest
from alvin_api_client.model.data_entity_lineage_children_response import DataEntityLineageChildrenResponse
from alvin_api_client.model.data_entity_lineage_data import DataEntityLineageData
from alvin_api_client.model.data_entity_lineage_graph_edge import DataEntityLineageGraphEdge
from alvin_api_client.model.data_entity_lineage_graph_node import DataEntityLineageGraphNode
from alvin_api_client.model.data_entity_lineage_list import DataEntityLineageList
from alvin_api_client.model.data_entity_lineage_list_item import DataEntityLineageListItem
from alvin_api_client.model.data_entity_lineage_list_request import DataEntityLineageListRequest
from alvin_api_client.model.data_entity_lineage_list_response import DataEntityLineageListResponse
from alvin_api_client.model.data_entity_lineage_result import DataEntityLineageResult
from alvin_api_client.model.data_entity_lineage_v2_request import DataEntityLineageV2Request
from alvin_api_client.model.data_entity_lineage_v2_response import DataEntityLineageV2Response
from alvin_api_client.model.data_entity_numerical_stat import DataEntityNumericalStat
from alvin_api_client.model.data_entity_numerical_stat_response import DataEntityNumericalStatResponse
from alvin_api_client.model.data_entity_numerical_stat_type import DataEntityNumericalStatType
from alvin_api_client.model.data_entity_run import DataEntityRun
from alvin_api_client.model.data_entity_run_facet_get import DataEntityRunFacetGet
from alvin_api_client.model.data_entity_run_get import DataEntityRunGet
from alvin_api_client.model.data_entity_run_job_mapping_get import DataEntityRunJobMappingGet
from alvin_api_client.model.data_entity_run_job_step_mapping_get import DataEntityRunJobStepMappingGet
from alvin_api_client.model.data_entity_run_status import DataEntityRunStatus
from alvin_api_client.model.data_entity_save_tag_connection_request import DataEntitySaveTagConnectionRequest
from alvin_api_client.model.data_entity_sub_type import DataEntitySubType
from alvin_api_client.model.data_entity_transformation import DataEntityTransformation
from alvin_api_client.model.data_entity_type import DataEntityType
from alvin_api_client.model.data_entity_usage_stat import DataEntityUsageStat
from alvin_api_client.model.data_entity_usage_stat_raw import DataEntityUsageStatRaw
from alvin_api_client.model.data_entity_usage_stats_report import DataEntityUsageStatsReport
from alvin_api_client.model.data_entity_usage_stats_request import DataEntityUsageStatsRequest
from alvin_api_client.model.data_entity_usage_type import DataEntityUsageType
from alvin_api_client.model.data_platform_aggregated_job_stat import DataPlatformAggregatedJobStat
from alvin_api_client.model.data_platform_airflow_create import DataPlatformAirflowCreate
from alvin_api_client.model.data_platform_big_query_create import DataPlatformBigQueryCreate
from alvin_api_client.model.data_platform_dbt_create import DataPlatformDBTCreate
from alvin_api_client.model.data_platform_databricks_create import DataPlatformDatabricksCreate
from alvin_api_client.model.data_platform_delete import DataPlatformDelete
from alvin_api_client.model.data_platform_full import DataPlatformFull
from alvin_api_client.model.data_platform_get import DataPlatformGet
from alvin_api_client.model.data_platform_hive_create import DataPlatformHiveCreate
from alvin_api_client.model.data_platform_hive_glue_create import DataPlatformHiveGlueCreate
from alvin_api_client.model.data_platform_job import DataPlatformJob
from alvin_api_client.model.data_platform_job_entity_aggregated_report import DataPlatformJobEntityAggregatedReport
from alvin_api_client.model.data_platform_job_execution_status import DataPlatformJobExecutionStatus
from alvin_api_client.model.data_platform_job_stat import DataPlatformJobStat
from alvin_api_client.model.data_platform_job_step import DataPlatformJobStep
from alvin_api_client.model.data_platform_job_step_aggregated_report import DataPlatformJobStepAggregatedReport
from alvin_api_client.model.data_platform_job_step_execution_status import DataPlatformJobStepExecutionStatus
from alvin_api_client.model.data_platform_job_step_id import DataPlatformJobStepId
from alvin_api_client.model.data_platform_job_step_report_type import DataPlatformJobStepReportType
from alvin_api_client.model.data_platform_job_step_request import DataPlatformJobStepRequest
from alvin_api_client.model.data_platform_job_step_sub_type import DataPlatformJobStepSubType
from alvin_api_client.model.data_platform_job_step_user import DataPlatformJobStepUser
from alvin_api_client.model.data_platform_job_type import DataPlatformJobType
from alvin_api_client.model.data_platform_looker_create import DataPlatformLookerCreate
from alvin_api_client.model.data_platform_mssql_create import DataPlatformMSSQLCreate
from alvin_api_client.model.data_platform_mode_create import DataPlatformModeCreate
from alvin_api_client.model.data_platform_my_sql_create import DataPlatformMySQLCreate
from alvin_api_client.model.data_platform_postgres_create import DataPlatformPostgresCreate
from alvin_api_client.model.data_platform_power_bi_create import DataPlatformPowerBICreate
from alvin_api_client.model.data_platform_redshift_create import DataPlatformRedshiftCreate
from alvin_api_client.model.data_platform_snowflake_create import DataPlatformSnowflakeCreate
from alvin_api_client.model.data_platform_status import DataPlatformStatus
from alvin_api_client.model.data_platform_tableau_create import DataPlatformTableauCreate
from alvin_api_client.model.data_platform_treasure_data_create import DataPlatformTreasureDataCreate
from alvin_api_client.model.data_platform_type import DataPlatformType
from alvin_api_client.model.data_tag import DataTag
from alvin_api_client.model.data_tag_bulk_apply import DataTagBulkApply
from alvin_api_client.model.data_tag_bulk_delete import DataTagBulkDelete
from alvin_api_client.model.data_tag_classification_type import DataTagClassificationType
from alvin_api_client.model.data_tag_connection_get import DataTagConnectionGet
from alvin_api_client.model.data_tag_created_in import DataTagCreatedIn
from alvin_api_client.model.data_tag_get import DataTagGet
from alvin_api_client.model.data_tag_request import DataTagRequest
from alvin_api_client.model.data_tag_request_delete import DataTagRequestDelete
from alvin_api_client.model.data_tag_request_v2 import DataTagRequestV2
from alvin_api_client.model.data_tag_rule import DataTagRule
from alvin_api_client.model.data_tag_rule_entity_type import DataTagRuleEntityType
from alvin_api_client.model.data_tag_rule_get import DataTagRuleGet
from alvin_api_client.model.data_tag_rule_propagation import DataTagRulePropagation
from alvin_api_client.model.data_tag_rule_type import DataTagRuleType
from alvin_api_client.model.data_tag_rules_request_delete import DataTagRulesRequestDelete
from alvin_api_client.model.data_tag_status import DataTagStatus
from alvin_api_client.model.data_tag_type import DataTagType
from alvin_api_client.model.data_tag_v2 import DataTagV2
from alvin_api_client.model.data_taxonomy_classification import DataTaxonomyClassification
from alvin_api_client.model.data_transformation_lineage import DataTransformationLineage
from alvin_api_client.model.databricks_account_details import DatabricksAccountDetails
from alvin_api_client.model.databricks_additional_config import DatabricksAdditionalConfig
from alvin_api_client.model.datadog_settings import DatadogSettings
from alvin_api_client.model.delete_parse_result import DeleteParseResult
from alvin_api_client.model.drop_parse_result import DropParseResult
from alvin_api_client.model.drop_type import DropType
from alvin_api_client.model.element_position import ElementPosition
from alvin_api_client.model.email_login_request import EmailLoginRequest
from alvin_api_client.model.entity_graph_connector_edge import EntityGraphConnectorEdge
from alvin_api_client.model.entity_graph_node import EntityGraphNode
from alvin_api_client.model.entity_graph_node_connector import EntityGraphNodeConnector
from alvin_api_client.model.environment_config import EnvironmentConfig
from alvin_api_client.model.event_type import EventType
from alvin_api_client.model.exchange_token_request import ExchangeTokenRequest
from alvin_api_client.model.experience import Experience
from alvin_api_client.model.experience_data import ExperienceData
from alvin_api_client.model.experience_status import ExperienceStatus
from alvin_api_client.model.experience_user import ExperienceUser
from alvin_api_client.model.experiences_settings import ExperiencesSettings
from alvin_api_client.model.extracted_simple_column import ExtractedSimpleColumn
from alvin_api_client.model.extracted_simple_table import ExtractedSimpleTable
from alvin_api_client.model.filter_data_payload import FilterDataPayload
from alvin_api_client.model.filter_match import FilterMatch
from alvin_api_client.model.filter_options import FilterOptions
from alvin_api_client.model.filter_type import FilterType
from alvin_api_client.model.filter_view import FilterView
from alvin_api_client.model.filters_response import FiltersResponse
from alvin_api_client.model.firebase_auth_provider import FirebaseAuthProvider
from alvin_api_client.model.firebase_auth_ui_config import FirebaseAuthUIConfig
from alvin_api_client.model.group_type import GroupType
from alvin_api_client.model.html_values import HTMLValues
from alvin_api_client.model.http_validation_error import HTTPValidationError
from alvin_api_client.model.healthcheck_response import HealthcheckResponse
from alvin_api_client.model.hive_account_details import HiveAccountDetails
from alvin_api_client.model.hive_additional_config import HiveAdditionalConfig
from alvin_api_client.model.hive_glue_account_details import HiveGlueAccountDetails
from alvin_api_client.model.hive_glue_additional_config import HiveGlueAdditionalConfig
from alvin_api_client.model.ia_entity_data import IAEntityData
from alvin_api_client.model.ia_job_data import IAJobData
from alvin_api_client.model.ia_platform_data import IAPlatformData
from alvin_api_client.model.ia_row import IARow
from alvin_api_client.model.ia_row_type import IARowType
from alvin_api_client.model.impact_analysis_node_list_response import ImpactAnalysisNodeListResponse
from alvin_api_client.model.impact_analysis_node_stats import ImpactAnalysisNodeStats
from alvin_api_client.model.impact_analysis_platform_request import ImpactAnalysisPlatformRequest
from alvin_api_client.model.impact_analysis_query_report import ImpactAnalysisQueryReport
from alvin_api_client.model.impact_analysis_query_request import ImpactAnalysisQueryRequest
from alvin_api_client.model.impact_analysis_query_validation import ImpactAnalysisQueryValidation
from alvin_api_client.model.impact_analysis_request import ImpactAnalysisRequest
from alvin_api_client.model.impact_analysis_response import ImpactAnalysisResponse
from alvin_api_client.model.impact_analysis_response_status import ImpactAnalysisResponseStatus
from alvin_api_client.model.impact_analysis_validation_payload import ImpactAnalysisValidationPayload
from alvin_api_client.model.impact_status import ImpactStatus
from alvin_api_client.model.job_entity_id import JobEntityID
from alvin_api_client.model.job_entity_usage_stats_report import JobEntityUsageStatsReport
from alvin_api_client.model.job_query_request import JobQueryRequest
from alvin_api_client.model.job_query_v1_response import JobQueryV1Response
from alvin_api_client.model.job_steps_agg_response_model import JobStepsAggResponseModel
from alvin_api_client.model.known_column import KnownColumn
from alvin_api_client.model.known_table import KnownTable
from alvin_api_client.model.known_table_type import KnownTableType
from alvin_api_client.model.limit_offset_page_api_keys_response import LimitOffsetPageAPIKeysResponse
from alvin_api_client.model.limit_offset_page_data_entity_get import LimitOffsetPageDataEntityGet
from alvin_api_client.model.limit_offset_page_data_entity_numerical_stat import LimitOffsetPageDataEntityNumericalStat
from alvin_api_client.model.limit_offset_page_data_entity_run_facet_get import LimitOffsetPageDataEntityRunFacetGet
from alvin_api_client.model.limit_offset_page_data_entity_run_get import LimitOffsetPageDataEntityRunGet
from alvin_api_client.model.limit_offset_page_data_entity_run_job_mapping_get import LimitOffsetPageDataEntityRunJobMappingGet
from alvin_api_client.model.limit_offset_page_data_entity_usage_stat_raw import LimitOffsetPageDataEntityUsageStatRaw
from alvin_api_client.model.limit_offset_page_data_entity_usage_stats_report import LimitOffsetPageDataEntityUsageStatsReport
from alvin_api_client.model.limit_offset_page_data_platform_job import LimitOffsetPageDataPlatformJob
from alvin_api_client.model.limit_offset_page_data_platform_job_entity_aggregated_report import LimitOffsetPageDataPlatformJobEntityAggregatedReport
from alvin_api_client.model.limit_offset_page_data_tag_connection_get import LimitOffsetPageDataTagConnectionGet
from alvin_api_client.model.limit_offset_page_data_tag_get import LimitOffsetPageDataTagGet
from alvin_api_client.model.limit_offset_page_data_tag_rule_get import LimitOffsetPageDataTagRuleGet
from alvin_api_client.model.limit_offset_page_manual_lineage_data import LimitOffsetPageManualLineageData
from alvin_api_client.model.lineage_connection_type import LineageConnectionType
from alvin_api_client.model.lineage_scope import LineageScope
from alvin_api_client.model.links_request import LinksRequest
from alvin_api_client.model.looker_additional_config import LookerAdditionalConfig
from alvin_api_client.model.looker_credentials import LookerCredentials
from alvin_api_client.model.looker_query_comment import LookerQueryComment
from alvin_api_client.model.mssql_account_details import MSSQLAccountDetails
from alvin_api_client.model.mssql_additional_config import MSSQLAdditionalConfig
from alvin_api_client.model.manual_lineage_data import ManualLineageData
from alvin_api_client.model.manual_lineage_data_request import ManualLineageDataRequest
from alvin_api_client.model.manual_lineage_entity_type_validation import ManualLineageEntityTypeValidation
from alvin_api_client.model.mode_additional_config import ModeAdditionalConfig
from alvin_api_client.model.mode_credentials import ModeCredentials
from alvin_api_client.model.my_sql_account_details import MySQLAccountDetails
from alvin_api_client.model.my_sql_additional_config import MySQLAdditionalConfig
from alvin_api_client.model.notification import Notification
from alvin_api_client.model.notification_config import NotificationConfig
from alvin_api_client.model.notification_provider import NotificationProvider
from alvin_api_client.model.notification_type import NotificationType
from alvin_api_client.model.onboarding_level import OnboardingLevel
from alvin_api_client.model.operator_type import OperatorType
from alvin_api_client.model.organization_get import OrganizationGet
from alvin_api_client.model.organization_status import OrganizationStatus
from alvin_api_client.model.page_search_display_payload import PageSearchDisplayPayload
from alvin_api_client.model.platform_build_data import PlatformBuildData
from alvin_api_client.model.platform_build_type import PlatformBuildType
from alvin_api_client.model.platform_classification import PlatformClassification
from alvin_api_client.model.popularity_values import PopularityValues
from alvin_api_client.model.position import Position
from alvin_api_client.model.postgres_account_details import PostgresAccountDetails
from alvin_api_client.model.postgres_additional_config import PostgresAdditionalConfig
from alvin_api_client.model.power_bi_additional_config import PowerBIAdditionalConfig
from alvin_api_client.model.power_bi_credentials import PowerBICredentials
from alvin_api_client.model.predefined_filter import PredefinedFilter
from alvin_api_client.model.processed_lineage_graph_data import ProcessedLineageGraphData
from alvin_api_client.model.product_config import ProductConfig
from alvin_api_client.model.query_builder import QueryBuilder
from alvin_api_client.model.query_comment import QueryComment
from alvin_api_client.model.query_create_mode import QueryCreateMode
from alvin_api_client.model.query_fingerprint import QueryFingerprint
from alvin_api_client.model.query_lineage_parse_result import QueryLineageParseResult
from alvin_api_client.model.query_parse_result import QueryParseResult
from alvin_api_client.model.query_type import QueryType
from alvin_api_client.model.redshift_account_details import RedshiftAccountDetails
from alvin_api_client.model.redshift_additional_config import RedshiftAdditionalConfig
from alvin_api_client.model.rule_element import RuleElement
from alvin_api_client.model.rule_element_value_type import RuleElementValueType
from alvin_api_client.model.rule_type import RuleType
from alvin_api_client.model.rule_value import RuleValue
from alvin_api_client.model.save_search_filter import SaveSearchFilter
from alvin_api_client.model.save_search_string_filter import SaveSearchStringFilter
from alvin_api_client.model.search_display_payload import SearchDisplayPayload
from alvin_api_client.model.search_node import SearchNode
from alvin_api_client.model.search_prefix import SearchPrefix
from alvin_api_client.model.search_usage_stat_type import SearchUsageStatType
from alvin_api_client.model.search_v2_response import SearchV2Response
from alvin_api_client.model.search_v2_response_payload import SearchV2ResponsePayload
from alvin_api_client.model.seen_table_at_level import SeenTableAtLevel
from alvin_api_client.model.sheet_settings import SheetSettings
from alvin_api_client.model.snowflake_account_details import SnowflakeAccountDetails
from alvin_api_client.model.snowflake_additional_config import SnowflakeAdditionalConfig
from alvin_api_client.model.sql_table import SqlTable
from alvin_api_client.model.stat_data_payload import StatDataPayload
from alvin_api_client.model.table_alter import TableAlter
from alvin_api_client.model.table_existence import TableExistence
from alvin_api_client.model.table_insert import TableInsert
from alvin_api_client.model.table_merge import TableMerge
from alvin_api_client.model.table_merge_action import TableMergeAction
from alvin_api_client.model.table_merge_match_action_type import TableMergeMatchActionType
from alvin_api_client.model.table_merge_match_type import TableMergeMatchType
from alvin_api_client.model.table_update import TableUpdate
from alvin_api_client.model.tableau_additional_config import TableauAdditionalConfig
from alvin_api_client.model.tableau_credentials import TableauCredentials
from alvin_api_client.model.tag_data_type import TagDataType
from alvin_api_client.model.taxonomy_classification_config import TaxonomyClassificationConfig
from alvin_api_client.model.tiny_url_response import TinyURLResponse
from alvin_api_client.model.token import Token
from alvin_api_client.model.treasure_data_credentials import TreasureDataCredentials
from alvin_api_client.model.tree_result_classification import TreeResultClassification
from alvin_api_client.model.truncate_result import TruncateResult
from alvin_api_client.model.user_activity_request import UserActivityRequest
from alvin_api_client.model.user_activity_response import UserActivityResponse
from alvin_api_client.model.user_activity_type import UserActivityType
from alvin_api_client.model.user_create import UserCreate
from alvin_api_client.model.user_create_request import UserCreateRequest
from alvin_api_client.model.user_get import UserGet
from alvin_api_client.model.user_invite_create import UserInviteCreate
from alvin_api_client.model.user_name_usage_stat import UserNameUsageStat
from alvin_api_client.model.user_organization_api_key_request import UserOrganizationAPIKeyRequest
from alvin_api_client.model.user_organization_api_key_response import UserOrganizationAPIKeyResponse
from alvin_api_client.model.user_persona import UserPersona
from alvin_api_client.model.user_role import UserRole
from alvin_api_client.model.validation_error import ValidationError



import pytest


@pytest.fixture(params=[
    (
        'get_client_config_api_v1_client_config_get',
        (
            ((
                [], {}
            ), lambda response: all(x in response for x in (
                'auth_config',
                'experiences_config',
                'notification_config',
                'product_analytics_config',
                'product_onboarding_config',
            ))),
        )
    ),

])
def endpoint_test_data(request):
    """Information to run a test for a Client's method (API endpoint).

    This fixture allows defining a python method of the client to test,
    by inputing sample data and then doing an arbitrary 'verification test' on
    the returned (response) data.

    Each of the Client's python methods corresponds to an API endpoint.
    """
    return type('TestData', (), {
        'method': request.param[0],
        'inputs': (test_data[0] for test_data in request.param[1]),
        'tests': (test_data[1] for test_data in request.param[1]),
    })



def test_endpoint(endpoint_test_data, localhost_api_client, default_api, test_client_method):
    """Test an API endpoint by calling its corresponding client's method.

    Each endpoint can be tested by inputing different parameters (with which the
    client method is invoked) and by testing the output on diverse criteria.
    """
    with localhost_api_client(8000) as api_client:
    
        api_instance = default_api(api_client)

        for (args, kwargs), assert_statement in zip(endpoint_test_data.inputs, endpoint_test_data.tests):
            test_client_method(
                api_instance,
                endpoint_test_data.method,
                (args, kwargs),
                assert_statement
            )
